@@ -129,14 +129,14 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
             closest_time = find_closest_time(prompt_time, subset_time_list)
 
             # check if matched time is 5 minutes away from prompt time
-            # if get_min_diff(prompt_time, closest_time) < 5:
-            battery_level = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
-                                     "Percentage"])[0]
-            charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
-                                       "isCharging"])[0]
-            # else:
-            #     battery_level = "NF"
-            #     charging_status = "NF"
+            if get_min_diff(prompt_time, closest_time) < 5:
+                battery_level = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
+                                         "Percentage"])[0]
+                charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
+                                           "isCharging"])[0]
+            else:
+                battery_level = "NF"
+                charging_status = "NF"
 
 
         matched_time_list.append(closest_time)
