@@ -120,11 +120,9 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
     feature_df['PROXIMITY_TO_SLEEP_TIME'] = feature16
 
     # - feature 14: MIMS Summary
-    mims_summary_df, readings_df, start_time_df = feature_engineering_ema.mims_summary.create_column(df_prompt['Actual_Prompt_Local_DateTime'],
+    df_mims = feature_engineering_ema.mims_summary.create_column(df_prompt['Actual_Prompt_Local_DateTime'],
                                                                  intermediate_participant_path, date_in_study)
-    feature_df = pd.concat([feature_df, mims_summary_df], axis=1)
-    feature_df = pd.concat([feature_df, readings_df], axis=1)
-    feature_df = pd.concat([feature_df, start_time_df], axis=1)
+    feature_df = pd.concat([feature_df, df_mims], axis=1)
 
 
     # save
